@@ -34,16 +34,12 @@ from azure.kusto.data import ClientRequestProperties, KustoClient, KustoConnecti
 from azure.kusto.data.exceptions import KustoServiceError
 
 from airflow.exceptions import AirflowException
+from airflow.providers.common.compat.sdk import BaseHook
 from airflow.providers.microsoft.azure.utils import (
     add_managed_identity_connection_widgets,
     get_sync_default_azure_credential,
 )
 
-try:
-    from airflow.sdk import BaseHook
-except ImportError:
-    from airflow.hooks.base import BaseHook  # type: ignore[attr-defined,no-redef]
-
 if TYPE_CHECKING:
     from azure.kusto.data.response import KustoResponseDataSet
 
