@@ -37,12 +37,12 @@ from azure.servicebus.management import (
     SubscriptionProperties,
 )
 
+from airflow.providers.common.compat.sdk import BaseHook
 from airflow.providers.microsoft.azure.utils import (
     add_managed_identity_connection_widgets,
     get_field,
     get_sync_default_azure_credential,
 )
-from airflow.providers.microsoft.azure.version_compat import BaseHook
 
 if TYPE_CHECKING:
     import datetime
@@ -353,7 +353,7 @@ class AdminClientHook(BaseAzureServiceBusHook):
                 lock_duration=lock_duration,
                 requires_session=requires_session,
                 default_message_time_to_live=default_message_time_to_live,
-                dead_lettering_on_ßmessage_expiration=dead_lettering_on_message_expiration,
+                dead_lettering_on_message_expiration=dead_lettering_on_message_expiration,
                 dead_lettering_on_filter_evaluation_exceptions=dead_lettering_on_filter_evaluation_exceptions,
                 max_delivery_count=max_delivery_count,
                 enable_batched_operations=enable_batched_operations,
