@@ -21,16 +21,13 @@ from collections.abc import Sequence
 from typing import TYPE_CHECKING, Any
 
 from airflow.exceptions import AirflowException
+from airflow.providers.common.compat.sdk import BaseOperator, BaseOperatorLink
 from airflow.providers.microsoft.azure.hooks.powerbi import PowerBIHook
 from airflow.providers.microsoft.azure.triggers.powerbi import (
     PowerBIDatasetListTrigger,
     PowerBITrigger,
     PowerBIWorkspaceListTrigger,
 )
-from airflow.providers.microsoft.azure.version_compat import (
-    BaseOperator,
-    BaseOperatorLink,
-)
 
 if TYPE_CHECKING:
     from msgraph_core import APIVersion
